[Bf-blender-cvs] SVN commit: /data/svn/bf-blender [50192] branches/soc-2011-tomato: Merging r50190 through r50191 from into soc-2011-tomato

Sergey Sharybin sergey.vfx at gmail.com
Fri Aug 24 18:11:12 CEST 2012


Revision: 50192
          http://projects.blender.org/scm/viewvc.php?view=rev&root=bf-blender&revision=50192
Author:   nazgul
Date:     2012-08-24 16:11:12 +0000 (Fri, 24 Aug 2012)
Log Message:
-----------
Merging r50190 through r50191 from  into soc-2011-tomato

Revision Links:
--------------
    http://projects.blender.org/scm/viewvc.php?view=rev&root=bf-blender&revision=50190
    http://projects.blender.org/scm/viewvc.php?view=rev&root=bf-blender&revision=50191

Modified Paths:
--------------
    branches/soc-2011-tomato/source/blender/bmesh/intern/bmesh_opdefines.c
    branches/soc-2011-tomato/source/blender/bmesh/operators/bmo_create.c
    branches/soc-2011-tomato/source/blender/editors/mesh/editmesh_tools.c
    branches/soc-2011-tomato/source/blender/editors/transform/transform_conversions.c

Property Changed:
----------------
    branches/soc-2011-tomato/
    branches/soc-2011-tomato/source/blender/editors/interface/interface.c
    branches/soc-2011-tomato/source/blender/editors/space_outliner/


Property changes on: branches/soc-2011-tomato
___________________________________________________________________
Modified: svn:mergeinfo
   - /branches/ge_harmony:42255,42279-42282,42286,42302,42338,42349,42616,42620,42698-42699,42739,42753,42773-42774,42832,44568,44597-44598,44793-44794
/branches/soc-2011-cucumber:37517,38166-38167,38177,38179-38180,38187,38242,38384,38387,38403-38404,38407,38968,38970,38973,39045,40845,42997-42998,43439
/branches/vgroup_modifiers:38694-39989
/trunk/blender:36831-50188
   + /branches/ge_harmony:42255,42279-42282,42286,42302,42338,42349,42616,42620,42698-42699,42739,42753,42773-42774,42832,44568,44597-44598,44793-44794
/branches/soc-2011-cucumber:37517,38166-38167,38177,38179-38180,38187,38242,38384,38387,38403-38404,38407,38968,38970,38973,39045,40845,42997-42998,43439
/branches/vgroup_modifiers:38694-39989
/trunk/blender:36831-50191

Modified: branches/soc-2011-tomato/source/blender/bmesh/intern/bmesh_opdefines.c
===================================================================
--- branches/soc-2011-tomato/source/blender/bmesh/intern/bmesh_opdefines.c	2012-08-24 16:09:48 UTC (rev 50191)
+++ branches/soc-2011-tomato/source/blender/bmesh/intern/bmesh_opdefines.c	2012-08-24 16:11:12 UTC (rev 50192)
@@ -408,6 +408,8 @@
 	"contextual_create",
 	{{BMO_OP_SLOT_ELEMENT_BUF, "geom"}, //input geometry.
 	 {BMO_OP_SLOT_ELEMENT_BUF, "faceout"},     /* newly-made face(s) */
+	/* note, this is for stand-alone edges only, not edges which are apart of newly created faces */
+	 {BMO_OP_SLOT_ELEMENT_BUF, "edgeout"},     /* newly-made edge(s) */
 	 {BMO_OP_SLOT_INT,         "mat_nr"},      /* material to use */
 	 {BMO_OP_SLOT_BOOL,        "use_smooth"},  /* material to use */
 	 {0, /* null-terminating sentinel */}},

Modified: branches/soc-2011-tomato/source/blender/bmesh/operators/bmo_create.c
===================================================================
--- branches/soc-2011-tomato/source/blender/bmesh/operators/bmo_create.c	2012-08-24 16:09:48 UTC (rev 50191)
+++ branches/soc-2011-tomato/source/blender/bmesh/operators/bmo_create.c	2012-08-24 16:11:12 UTC (rev 50192)
@@ -1415,6 +1415,7 @@
 		/* create edge */
 		e = BM_edge_create(bm, verts[0], verts[1], NULL, TRUE);
 		BMO_elem_flag_enable(bm, e, ELE_OUT);
+		BMO_slot_buffer_from_enabled_flag(bm, op, "edgeout", BM_EDGE, ELE_OUT);
 	}
 	else if (0) { /* nice feature but perhaps it should be a different tool? */
 
@@ -1460,6 +1461,7 @@
 				}
 			}
 		}
+		BMO_slot_buffer_from_enabled_flag(bm, op, "edgeout", BM_EDGE, ELE_OUT);
 		/* done creating edges */
 	}
 	else if (amount > 2) {


Property changes on: branches/soc-2011-tomato/source/blender/editors/interface/interface.c
___________________________________________________________________
Modified: svn:mergeinfo
   - /branches/ge_candy/source/blender/editors/interface/interface.c:45070-46163
/branches/ge_harmony/source/blender/editors/interface/interface.c:42255,42279-42282,42286,42302,42338,42349,42616,42620,42698-42699,42739,42753,42773-42774,42832,44568,44597-44598,44793-44794
/branches/soc-2011-cucumber/source/blender/editors/interface/interface.c:37517,38166-38167,38177,38179-38180,38187,38242,38384,38387,38403-38404,38407,38968,38970,38973,39045,40845,42997-42998,43439
/branches/vgroup_modifiers/source/blender/editors/interface/interface.c:38694-39989
/trunk/blender/source/blender/editors/interface/interface.c:36831-50188
   + /branches/ge_candy/source/blender/editors/interface/interface.c:45070-46163
/branches/ge_harmony/source/blender/editors/interface/interface.c:42255,42279-42282,42286,42302,42338,42349,42616,42620,42698-42699,42739,42753,42773-42774,42832,44568,44597-44598,44793-44794
/branches/soc-2011-cucumber/source/blender/editors/interface/interface.c:37517,38166-38167,38177,38179-38180,38187,38242,38384,38387,38403-38404,38407,38968,38970,38973,39045,40845,42997-42998,43439
/branches/vgroup_modifiers/source/blender/editors/interface/interface.c:38694-39989
/trunk/blender/source/blender/editors/interface/interface.c:36831-50191

Modified: branches/soc-2011-tomato/source/blender/editors/mesh/editmesh_tools.c
===================================================================
--- branches/soc-2011-tomato/source/blender/editors/mesh/editmesh_tools.c	2012-08-24 16:09:48 UTC (rev 50191)
+++ branches/soc-2011-tomato/source/blender/editors/mesh/editmesh_tools.c	2012-08-24 16:11:12 UTC (rev 50192)
@@ -1056,6 +1056,7 @@
 	
 	BMO_op_exec(em->bm, &bmop);
 	BMO_slot_buffer_hflag_enable(em->bm, &bmop, "faceout", BM_FACE, BM_ELEM_SELECT, TRUE);
+	BMO_slot_buffer_hflag_enable(em->bm, &bmop, "edgeout", BM_EDGE, BM_ELEM_SELECT, TRUE);
 
 	if (!EDBM_op_finish(em, &bmop, op, TRUE)) {
 		return OPERATOR_CANCELLED;


Property changes on: branches/soc-2011-tomato/source/blender/editors/space_outliner
___________________________________________________________________
Modified: svn:mergeinfo
   - /branches/soc-2011-cucumber/source/blender/editors/space_outliner:38968,38970,38973,39045,40845
/branches/soc-2011-pepper/source/blender/editors/space_outliner:36831-38987
/trunk/blender/source/blender/editors/space_outliner:36831-50188
   + /branches/soc-2011-cucumber/source/blender/editors/space_outliner:38968,38970,38973,39045,40845
/branches/soc-2011-pepper/source/blender/editors/space_outliner:36831-38987
/trunk/blender/source/blender/editors/space_outliner:36831-50191

Modified: branches/soc-2011-tomato/source/blender/editors/transform/transform_conversions.c
===================================================================
--- branches/soc-2011-tomato/source/blender/editors/transform/transform_conversions.c	2012-08-24 16:09:48 UTC (rev 50191)
+++ branches/soc-2011-tomato/source/blender/editors/transform/transform_conversions.c	2012-08-24 16:11:12 UTC (rev 50192)
@@ -4209,7 +4209,7 @@
 			for (a = 0; a < t->total; a++, td++) {
 				if ((seq != seq_prev) && (seq->depth == 0) && (seq->flag & SEQ_OVERLAP)) {
 					seq = ((TransDataSeq *)td->extra)->seq;
-					shuffle_seq(seqbasep, seq);
+					BKE_sequence_base_shuffle(seqbasep, seq, t->scene);
 				}
 
 				seq_prev = seq;
@@ -4244,7 +4244,7 @@
 								has_effect = TRUE;
 							}
 							else {
 								/* Tag seq with a non zero value, used by shuffle_seq_time to identify the ones to shuffle */
 								seq->tmp = (void *)1;
 							}
 						}
@@ -4289,7 +4289,7 @@
 						BKE_sequence_base_shuffle_time(seqbasep, t->scene);
 					}
 #else
-					shuffle_seq_time(seqbasep, t->scene);
+					BKE_sequence_base_shuffle_time(seqbasep, t->scene);
 #endif
 
 					if (has_effect) {
@@ -4340,6 +4340,9 @@
 			for (a = 0; a < t->total; a++, td++) {
 				seq = ((TransDataSeq *)td->extra)->seq;
 				if ((seq != seq_prev) && (seq->depth == 0)) {
+					if (seq->flag & SEQ_OVERLAP)
+						BKE_sequence_base_shuffle(seqbasep, seq, t->scene);
+
 					BKE_sequence_calc_disp(t->scene, seq);
 				}
 				seq_prev = seq;
@@ -4244,7 +4244,7 @@
 							}
 							else {
-								/* Tag seq with a non zero value, used by shuffle_seq_time to identify the ones to shuffle */
+								/* Tag seq with a non zero value, used by BKE_sequence_base_shuffle_time to identify the ones to shuffle */
 								seq->tmp = (void *)1;
 							}




More information about the Bf-blender-cvs mailing list